@@ -7,13 +7,13 @@ import unittest
 class TestAbcHierarchy(unittest.TestCase):
   """Test abc_hierarchy.py."""
 
-  def testGetSuperClasses(self):
+  def test_get_superclasses(self):
     superclasses = abc_hierarchy.GetSuperClasses()
     self.assertDictEqual(superclasses, abc_hierarchy.SUPERCLASSES)
     # Verify that we made a copy.
     self.assertIsNot(superclasses, abc_hierarchy.SUPERCLASSES)
 
-  def testGetSubClasses(self):
+  def test_get_subclasses(self):
     subclasses = abc_hierarchy.GetSubClasses()
     # Check one entry.
     self.assertSetEqual(
