@@ -14,7 +14,6 @@ rather than
   x: 'Union[Foo, Bar]'
 """
 
-import collections
 import enum
 import itertools
 
@@ -517,7 +516,7 @@ def _FlattenTypes(type_list) -> Tuple[Type, ...]:
       t.type_list if isinstance(t, _SetOfTypes) else [t]
       for t in type_list)
   # Remove duplicates, preserving order
-  unique = tuple(collections.OrderedDict.fromkeys(flattened))
+  unique = tuple(dict.fromkeys(flattened))
   return unique
 
 
@@ -645,10 +644,7 @@ def IsContainer(t):
   for p in t.bases:
     if isinstance(p, GenericType):
       base = p.base_type
-      # We need to check for Generic and Protocol again here because base may
-      # not yet have been resolved to a ClassType.
-      if (base.name in ('typing.Generic', 'typing.Protocol') or
-          isinstance(base, ClassType) and IsContainer(base.cls)):
+      if isinstance(base, ClassType) and IsContainer(base.cls):
         return True
   return False
 
