@@ -6,7 +6,13 @@ import sys
 from pytype.ast import debug
 from pytype.tools import arg_parser
 from pytype.tools.annotate_ast import annotate_ast
-from typed_ast import ast3
+
+# pylint: disable=g-import-not-at-top
+if sys.version_info >= (3, 8):
+  import ast as ast3
+else:
+  from typed_ast import ast3
+# pylint: enable=g-import-not-at-top
 
 
 def main():
